<?php
namespace Aws\Deadline\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWSDeadlineCloud** service.
 */
class DeadlineException extends AwsException {}
